"use strict";
/********************************************************************************
 * Copyright (C) 2021 Jon Radchenko and others.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MlFlowUiServerProxyContribution = exports.MlFlowUiInstanceBuilder = void 0;
const http_proxy_middleware_1 = require("http-proxy-middleware");
const inversify_1 = require("inversify");
const server_proxy_contribution_1 = require("theia-server-proxy-extension/lib/node/server-proxy-contribution");
const const_1 = require("../common/const");
const server_proxy_url_manager_1 = require("theia-server-proxy-extension/lib/common/server-proxy-url-manager");
let MlFlowUiInstanceBuilder = class MlFlowUiInstanceBuilder extends server_proxy_contribution_1.BaseServerProxyInstanceBuilder {
    constructor() {
        super(...arguments);
        this.serverProxy = const_1.Extension.ServerProxy;
    }
    async getCommand(_instanceId, context) {
        const port = await this.findAvailablePort();
        const command = [
            'mlflow',
            'ui',
            `--backend-store-uri=${context.backendStoreUri}`,
            `--port=${port}`
        ];
        return {
            command,
            port
        };
    }
};
MlFlowUiInstanceBuilder = __decorate([
    (0, inversify_1.injectable)()
], MlFlowUiInstanceBuilder);
exports.MlFlowUiInstanceBuilder = MlFlowUiInstanceBuilder;
let MlFlowUiServerProxyContribution = class MlFlowUiServerProxyContribution {
    constructor(serverProxyInstanceBuilder) {
        this.serverProxyInstanceBuilder = serverProxyInstanceBuilder;
        this.id = const_1.Extension.ID;
        this.name = const_1.Extension.Name;
    }
    getMiddleware(basePath, baseOptions) {
        const pathRewriter = {};
        pathRewriter[this.serverProxyUrlManager.getPathMatchRegex()] = '';
        baseOptions.pathRewrite = pathRewriter;
        const onProxyReq = baseOptions.onProxyReq;
        baseOptions.onProxyReq = (proxyReq, req, res) => {
            if (req.originalUrl.endsWith('/theia-container.html')) {
                // hack to handle mlflow trying to access the window's parent location, which doesn't work in electron
                // https://github.com/mlflow/mlflow/issues/3583
                const text = '<html><iframe src="./" style="border: none; margin: 0; padding: 0; width: 100%; height: 100%;" /></html>';
                req.body = text;
                res.status(200);
                res.setHeader('Content-Length', Buffer.byteLength(text));
                res.write(text);
                res.end();
            }
            else {
                onProxyReq === null || onProxyReq === void 0 ? void 0 : onProxyReq(proxyReq, req, res);
            }
        };
        return (0, http_proxy_middleware_1.createProxyMiddleware)(basePath, baseOptions);
    }
};
__decorate([
    (0, inversify_1.inject)(server_proxy_url_manager_1.ServerProxyUrlManager),
    __metadata("design:type", server_proxy_url_manager_1.ServerProxyUrlManager)
], MlFlowUiServerProxyContribution.prototype, "serverProxyUrlManager", void 0);
MlFlowUiServerProxyContribution = __decorate([
    (0, inversify_1.injectable)(),
    __param(0, (0, inversify_1.inject)(MlFlowUiInstanceBuilder)),
    __metadata("design:paramtypes", [MlFlowUiInstanceBuilder])
], MlFlowUiServerProxyContribution);
exports.MlFlowUiServerProxyContribution = MlFlowUiServerProxyContribution;
//# sourceMappingURL=mlflow-ui-server-proxy-contribution.js.map